# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSKArchives_sos.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import numbers_parser.generated.TSKArchives_pb2 as TSKArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSKArchives_sos.proto',
  package='TSKSOS',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15TSKArchives_sos.proto\x12\x06TSKSOS\x1a\x11TSKArchives.proto\"\x8c\x01\n\x1e\x46ixCorruptedDataCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x15\x63orrupted_digest_list\x18\x02 \x03(\t\x12\'\n\x1f\x63orrupted_digest_list_undefined\x18\x03 \x01(\x08'
  ,
  dependencies=[TSKArchives__pb2.DESCRIPTOR,])




_FIXCORRUPTEDDATACOMMANDARCHIVE = _descriptor.Descriptor(
  name='FixCorruptedDataCommandArchive',
  full_name='TSKSOS.FixCorruptedDataCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSKSOS.FixCorruptedDataCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corrupted_digest_list', full_name='TSKSOS.FixCorruptedDataCommandArchive.corrupted_digest_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corrupted_digest_list_undefined', full_name='TSKSOS.FixCorruptedDataCommandArchive.corrupted_digest_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=193,
)

_FIXCORRUPTEDDATACOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
DESCRIPTOR.message_types_by_name['FixCorruptedDataCommandArchive'] = _FIXCORRUPTEDDATACOMMANDARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FixCorruptedDataCommandArchive = _reflection.GeneratedProtocolMessageType('FixCorruptedDataCommandArchive', (_message.Message,), {
  'DESCRIPTOR' : _FIXCORRUPTEDDATACOMMANDARCHIVE,
  '__module__' : 'TSKArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSKSOS.FixCorruptedDataCommandArchive)
  })
_sym_db.RegisterMessage(FixCorruptedDataCommandArchive)


# @@protoc_insertion_point(module_scope)
