# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TNArchives.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import numbers_parser.generated.TSPMessages_pb2 as TSPMessages__pb2
import numbers_parser.generated.TSKArchives_pb2 as TSKArchives__pb2
import numbers_parser.generated.TSCHArchives_pb2 as TSCHArchives__pb2
import numbers_parser.generated.TSCEArchives_pb2 as TSCEArchives__pb2
import numbers_parser.generated.TSSArchives_pb2 as TSSArchives__pb2
import numbers_parser.generated.TSDArchives_pb2 as TSDArchives__pb2
import numbers_parser.generated.TSWPArchives_pb2 as TSWPArchives__pb2
import numbers_parser.generated.TSAArchives_pb2 as TSAArchives__pb2
import numbers_parser.generated.TSTArchives_pb2 as TSTArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TNArchives.proto',
  package='TN',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10TNArchives.proto\x12\x02TN\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x12TSCHArchives.proto\x1a\x12TSCEArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x12TSWPArchives.proto\x1a\x11TSAArchives.proto\x1a\x11TSTArchives.proto\"\xcd\x03\n\x13SheetUIStateArchive\x12\x12\n\nview_scale\x18\x01 \x02(\x02\x12#\n\x0fscroll_position\x18\x02 \x02(\x0b\x32\n.TSP.Point\x12\x1b\n\x13previous_view_scale\x18\x03 \x01(\x02\x12#\n\x1bscroll_position_is_unscaled\x18\x04 \x01(\x08\x12,\n\x18previous_scroll_position\x18\x05 \x01(\x0b\x32\n.TSP.Point\x12\x1d\n\x15scroll_position_valid\x18\x06 \x01(\x08\x12&\n\x1eprevious_scroll_position_valid\x18\x07 \x01(\x08\x12\x1f\n\x0cvisible_size\x18\x08 \x01(\x0b\x32\t.TSP.Size\x12(\n\x15previous_visible_size\x18\t \x01(\x0b\x32\t.TSP.Size\x12\x14\n\x0c\x64\x65vice_idiom\x18\n \x01(\r\x12\x31\n\x0eselection_path\x18\x0b \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12\x32\n\x1aselection_path_transformer\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\"s\n\"SheetUIStateDictionaryEntryArchive\x12\x1d\n\x05sheet\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12.\n\rsheet_uistate\x18\x02 \x02(\x0b\x32\x17.TN.SheetUIStateArchive\"r\n!UUIDSheetUIStateDictionaryArchive\x12\x1d\n\nsheet_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12.\n\rsheet_uistate\x18\x02 \x02(\x0b\x32\x17.TN.SheetUIStateArchive\"\xd6\x0b\n\x0eUIStateArchive\x12\x1e\n\x12\x61\x63tive_sheet_index\x18\x01 \x02(\rB\x02\x18\x01\x12)\n\rselected_info\x18\x02 \x03(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12R\n\x1esheet_uistate_dictionary_entry\x18\x03 \x03(\x0b\x32&.TN.SheetUIStateDictionaryEntryArchiveB\x02\x18\x01\x12\x32\n\x0ftable_selection\x18\x04 \x01(\x0b\x32\x15.TST.SelectionArchiveB\x02\x18\x01\x12\x1f\n\x13\x65\x64iting_sheet_index\x18\x05 \x01(\rB\x02\x18\x01\x12\x15\n\rdocument_mode\x18\x06 \x01(\x05\x12\\\n(edit_mode_sheet_uistate_dictionary_entry\x18\x07 \x03(\x0b\x32&.TN.SheetUIStateDictionaryEntryArchiveB\x02\x18\x01\x12\x1e\n\x12table_editing_mode\x18\x08 \x01(\x05\x42\x02\x18\x01\x12%\n\x19\x66orm_focused_record_index\x18\t \x01(\rB\x02\x18\x01\x12$\n\x18\x66orm_focused_field_index\x18\n \x01(\rB\x02\x18\x01\x12\x15\n\rin_chart_mode\x18\x0b \x01(\x08\x12\x36\n\x0f\x63hart_selection\x18\x0c \x01(\x0b\x32\x19.TN.ChartSelectionArchiveB\x02\x18\x01\x12+\n\x0fsheet_selection\x18\r \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12$\n\x16inspector_pane_visible\x18\x0e \x01(\x08:\x04true\x12h\n\x18inspector_pane_view_mode\x18\x0f \x01(\x0e\x32(.TN.UIStateArchive.InspectorPaneViewMode:\x1ckInspectorPaneViewModeFormat\x12%\n\x1dselected_quick_calc_functions\x18\x10 \x03(\r\x12(\n removed_all_quick_calc_functions\x18\x11 \x01(\x08\x12\x1a\n\x12show_canvas_guides\x18\x12 \x01(\x08\x12\x16\n\x0eshows_comments\x18\x13 \x01(\x08\x12)\n\x15\x64\x65sktop_window_origin\x18\x14 \x01(\x0b\x32\n.TSP.Point\x12&\n\x13\x64\x65sktop_window_size\x18\x15 \x01(\x0b\x32\t.TSP.Size\x12&\n\x13\x64\x65sktop_screen_size\x18\x16 \x01(\x0b\x32\t.TSP.Size\x12*\n\x0e\x63hart_ui_state\x18\x17 \x03(\x0b\x32\x12.TSCH.ChartUIState\x12\x31\n\x0eselection_path\x18\x18 \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12!\n\x19inspector_pane_autohidden\x18\x19 \x01(\x08\x12\x19\n\rshows_sidebar\x18\x1a \x01(\x08\x42\x02\x18\x01\x12\x14\n\x0cshows_rulers\x18\x1b \x01(\x08\x12L\n\x1duuid_sheet_uistate_dictionary\x18\x1c \x03(\x0b\x32%.TN.UUIDSheetUIStateDictionaryArchive\x12\x36\n\x1e\x66reehand_drawing_toolkit_state\x18\x1d \x01(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1aselection_path_transformer\x18\x1e \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10\x65\x64iting_disabled\x18\x1f \x01(\x08\"[\n\x15InspectorPaneViewMode\x12 \n\x1ckInspectorPaneViewModeFormat\x10\x00\x12 \n\x1ckInspectorPaneViewModeFilter\x10\x01\"I\n\x15SheetSelectionArchive\x12\x1d\n\x05sheet\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tpaginated\x18\x02 \x01(\x08\"A\n\x14\x46ormSelectionArchive\x12\x14\n\x0crecord_index\x18\x01 \x02(\r\x12\x13\n\x0b\x66ield_index\x18\x02 \x02(\r\";\n\x1b\x46ormBuilderSelectionArchive\x12\x1c\n\x14viewing_record_index\x18\x01 \x01(\r\"\"\n FormTableChooserSelectionArchive\"<\n\x14UndoRedoStateArchive\x12$\n\x08ui_state\x18\x01 \x02(\x0b\x32\x12.TN.UIStateArchive\"\x89\x03\n\x0f\x44ocumentArchive\x12\x1e\n\x06sheets\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12#\n\x05super\x18\x08 \x02(\x0b\x32\x14.TSA.DocumentArchive\x12.\n\x12\x63\x61lculation_engine\x18\x03 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\"\n\nstylesheet\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rsidebar_order\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05theme\x18\x06 \x02(\x0b\x32\x0e.TSP.Reference\x12#\n\x07uistate\x18\x07 \x01(\x0b\x32\x12.TN.UIStateArchive\x12*\n\x12\x63ustom_format_list\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12\x16\n\nprinter_id\x18\n \x01(\tB\x02\x18\x01\x12\x10\n\x08paper_id\x18\x0b \x01(\t\x12\x1c\n\tpage_size\x18\x0c \x01(\x0b\x32\t.TSP.Size\";\n\x12PlaceholderArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.ShapeInfoArchive\"\xb5\x06\n\x0cSheetArchive\x12\x0c\n\x04name\x18\x01 \x02(\t\x12&\n\x0e\x64rawable_infos\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12$\n\x1cin_portrait_page_orientation\x18\x03 \x01(\x08\x12\"\n\x16show_repeating_headers\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x19\n\x11show_page_numbers\x18\x05 \x01(\x08\x12\x15\n\ris_autofit_on\x18\x06 \x01(\x08\x12\x15\n\rcontent_scale\x18\x07 \x01(\x02\x12!\n\npage_order\x18\x08 \x01(\x0e\x32\r.TN.PageOrder\x12-\n\rprint_margins\x18\n \x01(\x0b\x32\x16.TSD.EdgeInsetsArchive\x12\x1f\n\x17using_start_page_number\x18\x0b \x01(\x08\x12\x19\n\x11start_page_number\x18\x0c \x01(\x05\x12\x19\n\x11page_header_inset\x18\r \x01(\x02\x12\x19\n\x11page_footer_inset\x18\x0e \x01(\x02\x12*\n\x0eheader_storage\x18\x0f \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12*\n\x0e\x66ooter_storage\x18\x10 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12/\n\x17userDefinedGuideStorage\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07headers\x18\x12 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07\x66ooters\x18\x13 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x19uses_single_header_footer\x18\x14 \x01(\x08\x12Q\n\x10layout_direction\x18\x15 \x01(\x0e\x32\x17.TN.PageLayoutDirection:\x1ePageLayoutDirectionLeftToRight\x12\x1d\n\x05style\x18\x16 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11print_backgrounds\x18\x17 \x01(\x08\x12\x1d\n\x15should_print_comments\x18\x18 \x01(\x08\"=\n\x1bSheetStylePropertiesArchive\x12\x1e\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\"\x88\x01\n\x11SheetStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\x02 \x01(\r\x12\x39\n\x10sheet_properties\x18\x03 \x01(\x0b\x32\x1f.TN.SheetStylePropertiesArchive\"^\n\x15\x46ormBasedSheetArchive\x12\x1f\n\x05super\x18\x01 \x02(\x0b\x32\x10.TN.SheetArchive\x12$\n\x08table_id\x18\x02 \x01(\x0b\x32\x12.TSP.CFUUIDArchive\"T\n\x0cThemeArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.ThemeArchive\x12\"\n\nprototypes\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"j\n\x1ePasteboardNativeStorageArchive\x12\x1d\n\x05sheet\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x08ui_state\x18\x02 \x01(\x0b\x32\x17.TN.SheetUIStateArchive\"\xc7\x03\n\x1b\x43hartMediatorFormulaStorage\x12+\n\rdata_formulae\x18\x01 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x30\n\x12row_label_formulae\x18\x03 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x30\n\x12\x63ol_label_formulae\x18\x04 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x11\n\tdirection\x18\x05 \x01(\x05\x12\x37\n\x19\x65rror_custom_pos_formulae\x18\x06 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x37\n\x19\x65rror_custom_neg_formulae\x18\x07 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12@\n\"error_custom_pos_scatterX_formulae\x18\x08 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12@\n\"error_custom_neg_scatterX_formulae\x18\t \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x0e\n\x06scheme\x18\n \x01(\x05\"\xcf\x01\n\x14\x43hartMediatorArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TSCH.ChartMediatorArchive\x12\x11\n\tentity_id\x18\x02 \x02(\t\x12\x31\n\x08\x66ormulas\x18\x03 \x01(\x0b\x32\x1f.TN.ChartMediatorFormulaStorage\x12\x1a\n\x12\x63olumns_are_series\x18\x04 \x01(\x08\x12*\n\x1eis_registered_with_calc_engine\x18\x05 \x01(\x08\x42\x02\x18\x01\"\xcf\x01\n\x15\x43hartSelectionArchive\x12.\n\treference\x18\x01 \x01(\x0b\x32\x1b.TSCE.RangeReferenceArchive\x12\x39\n\x10\x64\x65precated_super\x18\x02 \x01(\x0b\x32\x1b.TSCH.ChartSelectionArchiveB\x02\x18\x01\x12\x1d\n\x05\x63hart\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12,\n\x05super\x18\x04 \x01(\x0b\x32\x1d.TSD.DrawableSelectionArchive*?\n\tPageOrder\x12\x18\n\x14PageOrderTopToBottom\x10\x00\x12\x18\n\x14PageOrderLeftToRight\x10\x01*]\n\x13PageLayoutDirection\x12\"\n\x1ePageLayoutDirectionLeftToRight\x10\x00\x12\"\n\x1ePageLayoutDirectionRightToLeft\x10\x01'
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSCHArchives__pb2.DESCRIPTOR,TSCEArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSAArchives__pb2.DESCRIPTOR,TSTArchives__pb2.DESCRIPTOR,])

_PAGEORDER = _descriptor.EnumDescriptor(
  name='PageOrder',
  full_name='TN.PageOrder',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PageOrderTopToBottom', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PageOrderLeftToRight', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5344,
  serialized_end=5407,
)
_sym_db.RegisterEnumDescriptor(_PAGEORDER)

PageOrder = enum_type_wrapper.EnumTypeWrapper(_PAGEORDER)
_PAGELAYOUTDIRECTION = _descriptor.EnumDescriptor(
  name='PageLayoutDirection',
  full_name='TN.PageLayoutDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PageLayoutDirectionLeftToRight', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PageLayoutDirectionRightToLeft', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5409,
  serialized_end=5502,
)
_sym_db.RegisterEnumDescriptor(_PAGELAYOUTDIRECTION)

PageLayoutDirection = enum_type_wrapper.EnumTypeWrapper(_PAGELAYOUTDIRECTION)
PageOrderTopToBottom = 0
PageOrderLeftToRight = 1
PageLayoutDirectionLeftToRight = 0
PageLayoutDirectionRightToLeft = 1


_UISTATEARCHIVE_INSPECTORPANEVIEWMODE = _descriptor.EnumDescriptor(
  name='InspectorPaneViewMode',
  full_name='TN.UIStateArchive.InspectorPaneViewMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kInspectorPaneViewModeFormat', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='kInspectorPaneViewModeFilter', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2299,
  serialized_end=2390,
)
_sym_db.RegisterEnumDescriptor(_UISTATEARCHIVE_INSPECTORPANEVIEWMODE)


_SHEETUISTATEARCHIVE = _descriptor.Descriptor(
  name='SheetUIStateArchive',
  full_name='TN.SheetUIStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_scale', full_name='TN.SheetUIStateArchive.view_scale', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scroll_position', full_name='TN.SheetUIStateArchive.scroll_position', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_view_scale', full_name='TN.SheetUIStateArchive.previous_view_scale', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scroll_position_is_unscaled', full_name='TN.SheetUIStateArchive.scroll_position_is_unscaled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_scroll_position', full_name='TN.SheetUIStateArchive.previous_scroll_position', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scroll_position_valid', full_name='TN.SheetUIStateArchive.scroll_position_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_scroll_position_valid', full_name='TN.SheetUIStateArchive.previous_scroll_position_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible_size', full_name='TN.SheetUIStateArchive.visible_size', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_visible_size', full_name='TN.SheetUIStateArchive.previous_visible_size', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_idiom', full_name='TN.SheetUIStateArchive.device_idiom', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_path', full_name='TN.SheetUIStateArchive.selection_path', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_path_transformer', full_name='TN.SheetUIStateArchive.selection_path_transformer', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=660,
)


_SHEETUISTATEDICTIONARYENTRYARCHIVE = _descriptor.Descriptor(
  name='SheetUIStateDictionaryEntryArchive',
  full_name='TN.SheetUIStateDictionaryEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.SheetUIStateDictionaryEntryArchive.sheet', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uistate', full_name='TN.SheetUIStateDictionaryEntryArchive.sheet_uistate', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=777,
)


_UUIDSHEETUISTATEDICTIONARYARCHIVE = _descriptor.Descriptor(
  name='UUIDSheetUIStateDictionaryArchive',
  full_name='TN.UUIDSheetUIStateDictionaryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet_uuid', full_name='TN.UUIDSheetUIStateDictionaryArchive.sheet_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uistate', full_name='TN.UUIDSheetUIStateDictionaryArchive.sheet_uistate', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=893,
)


_UISTATEARCHIVE = _descriptor.Descriptor(
  name='UIStateArchive',
  full_name='TN.UIStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_sheet_index', full_name='TN.UIStateArchive.active_sheet_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_info', full_name='TN.UIStateArchive.selected_info', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uistate_dictionary_entry', full_name='TN.UIStateArchive.sheet_uistate_dictionary_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_selection', full_name='TN.UIStateArchive.table_selection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editing_sheet_index', full_name='TN.UIStateArchive.editing_sheet_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_mode', full_name='TN.UIStateArchive.document_mode', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edit_mode_sheet_uistate_dictionary_entry', full_name='TN.UIStateArchive.edit_mode_sheet_uistate_dictionary_entry', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_editing_mode', full_name='TN.UIStateArchive.table_editing_mode', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='form_focused_record_index', full_name='TN.UIStateArchive.form_focused_record_index', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='form_focused_field_index', full_name='TN.UIStateArchive.form_focused_field_index', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_chart_mode', full_name='TN.UIStateArchive.in_chart_mode', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_selection', full_name='TN.UIStateArchive.chart_selection', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_selection', full_name='TN.UIStateArchive.sheet_selection', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inspector_pane_visible', full_name='TN.UIStateArchive.inspector_pane_visible', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inspector_pane_view_mode', full_name='TN.UIStateArchive.inspector_pane_view_mode', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_quick_calc_functions', full_name='TN.UIStateArchive.selected_quick_calc_functions', index=15,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed_all_quick_calc_functions', full_name='TN.UIStateArchive.removed_all_quick_calc_functions', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_canvas_guides', full_name='TN.UIStateArchive.show_canvas_guides', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shows_comments', full_name='TN.UIStateArchive.shows_comments', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_window_origin', full_name='TN.UIStateArchive.desktop_window_origin', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_window_size', full_name='TN.UIStateArchive.desktop_window_size', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_screen_size', full_name='TN.UIStateArchive.desktop_screen_size', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_ui_state', full_name='TN.UIStateArchive.chart_ui_state', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_path', full_name='TN.UIStateArchive.selection_path', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inspector_pane_autohidden', full_name='TN.UIStateArchive.inspector_pane_autohidden', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shows_sidebar', full_name='TN.UIStateArchive.shows_sidebar', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shows_rulers', full_name='TN.UIStateArchive.shows_rulers', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid_sheet_uistate_dictionary', full_name='TN.UIStateArchive.uuid_sheet_uistate_dictionary', index=27,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freehand_drawing_toolkit_state', full_name='TN.UIStateArchive.freehand_drawing_toolkit_state', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_path_transformer', full_name='TN.UIStateArchive.selection_path_transformer', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editing_disabled', full_name='TN.UIStateArchive.editing_disabled', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UISTATEARCHIVE_INSPECTORPANEVIEWMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=2390,
)


_SHEETSELECTIONARCHIVE = _descriptor.Descriptor(
  name='SheetSelectionArchive',
  full_name='TN.SheetSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.SheetSelectionArchive.sheet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paginated', full_name='TN.SheetSelectionArchive.paginated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2392,
  serialized_end=2465,
)


_FORMSELECTIONARCHIVE = _descriptor.Descriptor(
  name='FormSelectionArchive',
  full_name='TN.FormSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_index', full_name='TN.FormSelectionArchive.record_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_index', full_name='TN.FormSelectionArchive.field_index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2467,
  serialized_end=2532,
)


_FORMBUILDERSELECTIONARCHIVE = _descriptor.Descriptor(
  name='FormBuilderSelectionArchive',
  full_name='TN.FormBuilderSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewing_record_index', full_name='TN.FormBuilderSelectionArchive.viewing_record_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2534,
  serialized_end=2593,
)


_FORMTABLECHOOSERSELECTIONARCHIVE = _descriptor.Descriptor(
  name='FormTableChooserSelectionArchive',
  full_name='TN.FormTableChooserSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2629,
)


_UNDOREDOSTATEARCHIVE = _descriptor.Descriptor(
  name='UndoRedoStateArchive',
  full_name='TN.UndoRedoStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ui_state', full_name='TN.UndoRedoStateArchive.ui_state', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2631,
  serialized_end=2691,
)


_DOCUMENTARCHIVE = _descriptor.Descriptor(
  name='DocumentArchive',
  full_name='TN.DocumentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheets', full_name='TN.DocumentArchive.sheets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.DocumentArchive.super', index=1,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_engine', full_name='TN.DocumentArchive.calculation_engine', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stylesheet', full_name='TN.DocumentArchive.stylesheet', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sidebar_order', full_name='TN.DocumentArchive.sidebar_order', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TN.DocumentArchive.theme', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uistate', full_name='TN.DocumentArchive.uistate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_format_list', full_name='TN.DocumentArchive.custom_format_list', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='printer_id', full_name='TN.DocumentArchive.printer_id', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paper_id', full_name='TN.DocumentArchive.paper_id', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='TN.DocumentArchive.page_size', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2694,
  serialized_end=3087,
)


_PLACEHOLDERARCHIVE = _descriptor.Descriptor(
  name='PlaceholderArchive',
  full_name='TN.PlaceholderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.PlaceholderArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3089,
  serialized_end=3148,
)


_SHEETARCHIVE = _descriptor.Descriptor(
  name='SheetArchive',
  full_name='TN.SheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TN.SheetArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drawable_infos', full_name='TN.SheetArchive.drawable_infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_portrait_page_orientation', full_name='TN.SheetArchive.in_portrait_page_orientation', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_repeating_headers', full_name='TN.SheetArchive.show_repeating_headers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_page_numbers', full_name='TN.SheetArchive.show_page_numbers', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_autofit_on', full_name='TN.SheetArchive.is_autofit_on', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_scale', full_name='TN.SheetArchive.content_scale', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_order', full_name='TN.SheetArchive.page_order', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_margins', full_name='TN.SheetArchive.print_margins', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='using_start_page_number', full_name='TN.SheetArchive.using_start_page_number', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_page_number', full_name='TN.SheetArchive.start_page_number', index=10,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_header_inset', full_name='TN.SheetArchive.page_header_inset', index=11,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_footer_inset', full_name='TN.SheetArchive.page_footer_inset', index=12,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_storage', full_name='TN.SheetArchive.header_storage', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer_storage', full_name='TN.SheetArchive.footer_storage', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userDefinedGuideStorage', full_name='TN.SheetArchive.userDefinedGuideStorage', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='TN.SheetArchive.headers', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footers', full_name='TN.SheetArchive.footers', index=17,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uses_single_header_footer', full_name='TN.SheetArchive.uses_single_header_footer', index=18,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layout_direction', full_name='TN.SheetArchive.layout_direction', index=19,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='TN.SheetArchive.style', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_backgrounds', full_name='TN.SheetArchive.print_backgrounds', index=21,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='should_print_comments', full_name='TN.SheetArchive.should_print_comments', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3151,
  serialized_end=3972,
)


_SHEETSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='SheetStylePropertiesArchive',
  full_name='TN.SheetStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='TN.SheetStylePropertiesArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3974,
  serialized_end=4035,
)


_SHEETSTYLEARCHIVE = _descriptor.Descriptor(
  name='SheetStyleArchive',
  full_name='TN.SheetStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.SheetStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TN.SheetStyleArchive.override_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_properties', full_name='TN.SheetStyleArchive.sheet_properties', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4038,
  serialized_end=4174,
)


_FORMBASEDSHEETARCHIVE = _descriptor.Descriptor(
  name='FormBasedSheetArchive',
  full_name='TN.FormBasedSheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.FormBasedSheetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TN.FormBasedSheetArchive.table_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4176,
  serialized_end=4270,
)


_THEMEARCHIVE = _descriptor.Descriptor(
  name='ThemeArchive',
  full_name='TN.ThemeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.ThemeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prototypes', full_name='TN.ThemeArchive.prototypes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4272,
  serialized_end=4356,
)


_PASTEBOARDNATIVESTORAGEARCHIVE = _descriptor.Descriptor(
  name='PasteboardNativeStorageArchive',
  full_name='TN.PasteboardNativeStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.PasteboardNativeStorageArchive.sheet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ui_state', full_name='TN.PasteboardNativeStorageArchive.ui_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4358,
  serialized_end=4464,
)


_CHARTMEDIATORFORMULASTORAGE = _descriptor.Descriptor(
  name='ChartMediatorFormulaStorage',
  full_name='TN.ChartMediatorFormulaStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_formulae', full_name='TN.ChartMediatorFormulaStorage.data_formulae', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='row_label_formulae', full_name='TN.ChartMediatorFormulaStorage.row_label_formulae', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='col_label_formulae', full_name='TN.ChartMediatorFormulaStorage.col_label_formulae', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TN.ChartMediatorFormulaStorage.direction', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_custom_pos_formulae', full_name='TN.ChartMediatorFormulaStorage.error_custom_pos_formulae', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_custom_neg_formulae', full_name='TN.ChartMediatorFormulaStorage.error_custom_neg_formulae', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_custom_pos_scatterX_formulae', full_name='TN.ChartMediatorFormulaStorage.error_custom_pos_scatterX_formulae', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_custom_neg_scatterX_formulae', full_name='TN.ChartMediatorFormulaStorage.error_custom_neg_scatterX_formulae', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='TN.ChartMediatorFormulaStorage.scheme', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4467,
  serialized_end=4922,
)


_CHARTMEDIATORARCHIVE = _descriptor.Descriptor(
  name='ChartMediatorArchive',
  full_name='TN.ChartMediatorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.ChartMediatorArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_id', full_name='TN.ChartMediatorArchive.entity_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formulas', full_name='TN.ChartMediatorArchive.formulas', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns_are_series', full_name='TN.ChartMediatorArchive.columns_are_series', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_registered_with_calc_engine', full_name='TN.ChartMediatorArchive.is_registered_with_calc_engine', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4925,
  serialized_end=5132,
)


_CHARTSELECTIONARCHIVE = _descriptor.Descriptor(
  name='ChartSelectionArchive',
  full_name='TN.ChartSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='TN.ChartSelectionArchive.reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_super', full_name='TN.ChartSelectionArchive.deprecated_super', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart', full_name='TN.ChartSelectionArchive.chart', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.ChartSelectionArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5135,
  serialized_end=5342,
)

_SHEETUISTATEARCHIVE.fields_by_name['scroll_position'].message_type = TSPMessages__pb2._POINT
_SHEETUISTATEARCHIVE.fields_by_name['previous_scroll_position'].message_type = TSPMessages__pb2._POINT
_SHEETUISTATEARCHIVE.fields_by_name['visible_size'].message_type = TSPMessages__pb2._SIZE
_SHEETUISTATEARCHIVE.fields_by_name['previous_visible_size'].message_type = TSPMessages__pb2._SIZE
_SHEETUISTATEARCHIVE.fields_by_name['selection_path'].message_type = TSKArchives__pb2._SELECTIONPATHARCHIVE
_SHEETUISTATEARCHIVE.fields_by_name['selection_path_transformer'].message_type = TSPMessages__pb2._REFERENCE
_SHEETUISTATEDICTIONARYENTRYARCHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_SHEETUISTATEDICTIONARYENTRYARCHIVE.fields_by_name['sheet_uistate'].message_type = _SHEETUISTATEARCHIVE
_UUIDSHEETUISTATEDICTIONARYARCHIVE.fields_by_name['sheet_uuid'].message_type = TSPMessages__pb2._UUID
_UUIDSHEETUISTATEDICTIONARYARCHIVE.fields_by_name['sheet_uistate'].message_type = _SHEETUISTATEARCHIVE
_UISTATEARCHIVE.fields_by_name['selected_info'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['sheet_uistate_dictionary_entry'].message_type = _SHEETUISTATEDICTIONARYENTRYARCHIVE
_UISTATEARCHIVE.fields_by_name['table_selection'].message_type = TSTArchives__pb2._SELECTIONARCHIVE
_UISTATEARCHIVE.fields_by_name['edit_mode_sheet_uistate_dictionary_entry'].message_type = _SHEETUISTATEDICTIONARYENTRYARCHIVE
_UISTATEARCHIVE.fields_by_name['chart_selection'].message_type = _CHARTSELECTIONARCHIVE
_UISTATEARCHIVE.fields_by_name['sheet_selection'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['inspector_pane_view_mode'].enum_type = _UISTATEARCHIVE_INSPECTORPANEVIEWMODE
_UISTATEARCHIVE.fields_by_name['desktop_window_origin'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['desktop_window_size'].message_type = TSPMessages__pb2._SIZE
_UISTATEARCHIVE.fields_by_name['desktop_screen_size'].message_type = TSPMessages__pb2._SIZE
_UISTATEARCHIVE.fields_by_name['chart_ui_state'].message_type = TSCHArchives__pb2._CHARTUISTATE
_UISTATEARCHIVE.fields_by_name['selection_path'].message_type = TSKArchives__pb2._SELECTIONPATHARCHIVE
_UISTATEARCHIVE.fields_by_name['uuid_sheet_uistate_dictionary'].message_type = _UUIDSHEETUISTATEDICTIONARYARCHIVE
_UISTATEARCHIVE.fields_by_name['freehand_drawing_toolkit_state'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['selection_path_transformer'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE_INSPECTORPANEVIEWMODE.containing_type = _UISTATEARCHIVE
_SHEETSELECTIONARCHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_UNDOREDOSTATEARCHIVE.fields_by_name['ui_state'].message_type = _UISTATEARCHIVE
_DOCUMENTARCHIVE.fields_by_name['sheets'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['super'].message_type = TSAArchives__pb2._DOCUMENTARCHIVE
_DOCUMENTARCHIVE.fields_by_name['calculation_engine'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['sidebar_order'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['uistate'].message_type = _UISTATEARCHIVE
_DOCUMENTARCHIVE.fields_by_name['custom_format_list'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['page_size'].message_type = TSPMessages__pb2._SIZE
_PLACEHOLDERARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._SHAPEINFOARCHIVE
_SHEETARCHIVE.fields_by_name['drawable_infos'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['page_order'].enum_type = _PAGEORDER
_SHEETARCHIVE.fields_by_name['print_margins'].message_type = TSDArchives__pb2._EDGEINSETSARCHIVE
_SHEETARCHIVE.fields_by_name['header_storage'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['footer_storage'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['userDefinedGuideStorage'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['headers'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['footers'].message_type = TSPMessages__pb2._REFERENCE
_SHEETARCHIVE.fields_by_name['layout_direction'].enum_type = _PAGELAYOUTDIRECTION
_SHEETARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_SHEETSTYLEPROPERTIESARCHIVE.fields_by_name['fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_SHEETSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_SHEETSTYLEARCHIVE.fields_by_name['sheet_properties'].message_type = _SHEETSTYLEPROPERTIESARCHIVE
_FORMBASEDSHEETARCHIVE.fields_by_name['super'].message_type = _SHEETARCHIVE
_FORMBASEDSHEETARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_THEMEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._THEMEARCHIVE
_THEMEARCHIVE.fields_by_name['prototypes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['ui_state'].message_type = _SHEETUISTATEARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['data_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['row_label_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['col_label_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['error_custom_pos_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['error_custom_neg_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['error_custom_pos_scatterX_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORFORMULASTORAGE.fields_by_name['error_custom_neg_scatterX_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CHARTMEDIATORARCHIVE.fields_by_name['super'].message_type = TSCHArchives__pb2._CHARTMEDIATORARCHIVE
_CHARTMEDIATORARCHIVE.fields_by_name['formulas'].message_type = _CHARTMEDIATORFORMULASTORAGE
_CHARTSELECTIONARCHIVE.fields_by_name['reference'].message_type = TSCEArchives__pb2._RANGEREFERENCEARCHIVE
_CHARTSELECTIONARCHIVE.fields_by_name['deprecated_super'].message_type = TSCHArchives__pb2._CHARTSELECTIONARCHIVE
_CHARTSELECTIONARCHIVE.fields_by_name['chart'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSELECTIONARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLESELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['SheetUIStateArchive'] = _SHEETUISTATEARCHIVE
DESCRIPTOR.message_types_by_name['SheetUIStateDictionaryEntryArchive'] = _SHEETUISTATEDICTIONARYENTRYARCHIVE
DESCRIPTOR.message_types_by_name['UUIDSheetUIStateDictionaryArchive'] = _UUIDSHEETUISTATEDICTIONARYARCHIVE
DESCRIPTOR.message_types_by_name['UIStateArchive'] = _UISTATEARCHIVE
DESCRIPTOR.message_types_by_name['SheetSelectionArchive'] = _SHEETSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FormSelectionArchive'] = _FORMSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FormBuilderSelectionArchive'] = _FORMBUILDERSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FormTableChooserSelectionArchive'] = _FORMTABLECHOOSERSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['UndoRedoStateArchive'] = _UNDOREDOSTATEARCHIVE
DESCRIPTOR.message_types_by_name['DocumentArchive'] = _DOCUMENTARCHIVE
DESCRIPTOR.message_types_by_name['PlaceholderArchive'] = _PLACEHOLDERARCHIVE
DESCRIPTOR.message_types_by_name['SheetArchive'] = _SHEETARCHIVE
DESCRIPTOR.message_types_by_name['SheetStylePropertiesArchive'] = _SHEETSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['SheetStyleArchive'] = _SHEETSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['FormBasedSheetArchive'] = _FORMBASEDSHEETARCHIVE
DESCRIPTOR.message_types_by_name['ThemeArchive'] = _THEMEARCHIVE
DESCRIPTOR.message_types_by_name['PasteboardNativeStorageArchive'] = _PASTEBOARDNATIVESTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['ChartMediatorFormulaStorage'] = _CHARTMEDIATORFORMULASTORAGE
DESCRIPTOR.message_types_by_name['ChartMediatorArchive'] = _CHARTMEDIATORARCHIVE
DESCRIPTOR.message_types_by_name['ChartSelectionArchive'] = _CHARTSELECTIONARCHIVE
DESCRIPTOR.enum_types_by_name['PageOrder'] = _PAGEORDER
DESCRIPTOR.enum_types_by_name['PageLayoutDirection'] = _PAGELAYOUTDIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SheetUIStateArchive = _reflection.GeneratedProtocolMessageType('SheetUIStateArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETUISTATEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetUIStateArchive)
  })
_sym_db.RegisterMessage(SheetUIStateArchive)

SheetUIStateDictionaryEntryArchive = _reflection.GeneratedProtocolMessageType('SheetUIStateDictionaryEntryArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETUISTATEDICTIONARYENTRYARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetUIStateDictionaryEntryArchive)
  })
_sym_db.RegisterMessage(SheetUIStateDictionaryEntryArchive)

UUIDSheetUIStateDictionaryArchive = _reflection.GeneratedProtocolMessageType('UUIDSheetUIStateDictionaryArchive', (_message.Message,), {
  'DESCRIPTOR' : _UUIDSHEETUISTATEDICTIONARYARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.UUIDSheetUIStateDictionaryArchive)
  })
_sym_db.RegisterMessage(UUIDSheetUIStateDictionaryArchive)

UIStateArchive = _reflection.GeneratedProtocolMessageType('UIStateArchive', (_message.Message,), {
  'DESCRIPTOR' : _UISTATEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.UIStateArchive)
  })
_sym_db.RegisterMessage(UIStateArchive)

SheetSelectionArchive = _reflection.GeneratedProtocolMessageType('SheetSelectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETSELECTIONARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetSelectionArchive)
  })
_sym_db.RegisterMessage(SheetSelectionArchive)

FormSelectionArchive = _reflection.GeneratedProtocolMessageType('FormSelectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMSELECTIONARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormSelectionArchive)
  })
_sym_db.RegisterMessage(FormSelectionArchive)

FormBuilderSelectionArchive = _reflection.GeneratedProtocolMessageType('FormBuilderSelectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMBUILDERSELECTIONARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormBuilderSelectionArchive)
  })
_sym_db.RegisterMessage(FormBuilderSelectionArchive)

FormTableChooserSelectionArchive = _reflection.GeneratedProtocolMessageType('FormTableChooserSelectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMTABLECHOOSERSELECTIONARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormTableChooserSelectionArchive)
  })
_sym_db.RegisterMessage(FormTableChooserSelectionArchive)

UndoRedoStateArchive = _reflection.GeneratedProtocolMessageType('UndoRedoStateArchive', (_message.Message,), {
  'DESCRIPTOR' : _UNDOREDOSTATEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.UndoRedoStateArchive)
  })
_sym_db.RegisterMessage(UndoRedoStateArchive)

DocumentArchive = _reflection.GeneratedProtocolMessageType('DocumentArchive', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.DocumentArchive)
  })
_sym_db.RegisterMessage(DocumentArchive)

PlaceholderArchive = _reflection.GeneratedProtocolMessageType('PlaceholderArchive', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.PlaceholderArchive)
  })
_sym_db.RegisterMessage(PlaceholderArchive)

SheetArchive = _reflection.GeneratedProtocolMessageType('SheetArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetArchive)
  })
_sym_db.RegisterMessage(SheetArchive)

SheetStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('SheetStylePropertiesArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETSTYLEPROPERTIESARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetStylePropertiesArchive)
  })
_sym_db.RegisterMessage(SheetStylePropertiesArchive)

SheetStyleArchive = _reflection.GeneratedProtocolMessageType('SheetStyleArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETSTYLEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetStyleArchive)
  })
_sym_db.RegisterMessage(SheetStyleArchive)

FormBasedSheetArchive = _reflection.GeneratedProtocolMessageType('FormBasedSheetArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMBASEDSHEETARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormBasedSheetArchive)
  })
_sym_db.RegisterMessage(FormBasedSheetArchive)

ThemeArchive = _reflection.GeneratedProtocolMessageType('ThemeArchive', (_message.Message,), {
  'DESCRIPTOR' : _THEMEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.ThemeArchive)
  })
_sym_db.RegisterMessage(ThemeArchive)

PasteboardNativeStorageArchive = _reflection.GeneratedProtocolMessageType('PasteboardNativeStorageArchive', (_message.Message,), {
  'DESCRIPTOR' : _PASTEBOARDNATIVESTORAGEARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.PasteboardNativeStorageArchive)
  })
_sym_db.RegisterMessage(PasteboardNativeStorageArchive)

ChartMediatorFormulaStorage = _reflection.GeneratedProtocolMessageType('ChartMediatorFormulaStorage', (_message.Message,), {
  'DESCRIPTOR' : _CHARTMEDIATORFORMULASTORAGE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.ChartMediatorFormulaStorage)
  })
_sym_db.RegisterMessage(ChartMediatorFormulaStorage)

ChartMediatorArchive = _reflection.GeneratedProtocolMessageType('ChartMediatorArchive', (_message.Message,), {
  'DESCRIPTOR' : _CHARTMEDIATORARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.ChartMediatorArchive)
  })
_sym_db.RegisterMessage(ChartMediatorArchive)

ChartSelectionArchive = _reflection.GeneratedProtocolMessageType('ChartSelectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _CHARTSELECTIONARCHIVE,
  '__module__' : 'TNArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.ChartSelectionArchive)
  })
_sym_db.RegisterMessage(ChartSelectionArchive)


_UISTATEARCHIVE.fields_by_name['active_sheet_index']._options = None
_UISTATEARCHIVE.fields_by_name['selected_info']._options = None
_UISTATEARCHIVE.fields_by_name['sheet_uistate_dictionary_entry']._options = None
_UISTATEARCHIVE.fields_by_name['table_selection']._options = None
_UISTATEARCHIVE.fields_by_name['editing_sheet_index']._options = None
_UISTATEARCHIVE.fields_by_name['edit_mode_sheet_uistate_dictionary_entry']._options = None
_UISTATEARCHIVE.fields_by_name['table_editing_mode']._options = None
_UISTATEARCHIVE.fields_by_name['form_focused_record_index']._options = None
_UISTATEARCHIVE.fields_by_name['form_focused_field_index']._options = None
_UISTATEARCHIVE.fields_by_name['chart_selection']._options = None
_UISTATEARCHIVE.fields_by_name['sheet_selection']._options = None
_UISTATEARCHIVE.fields_by_name['shows_sidebar']._options = None
_DOCUMENTARCHIVE.fields_by_name['calculation_engine']._options = None
_DOCUMENTARCHIVE.fields_by_name['printer_id']._options = None
_SHEETARCHIVE.fields_by_name['show_repeating_headers']._options = None
_SHEETARCHIVE.fields_by_name['header_storage']._options = None
_SHEETARCHIVE.fields_by_name['footer_storage']._options = None
_CHARTMEDIATORARCHIVE.fields_by_name['is_registered_with_calc_engine']._options = None
_CHARTSELECTIONARCHIVE.fields_by_name['deprecated_super']._options = None
# @@protoc_insertion_point(module_scope)
