# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TNCommandArchives_sos.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import numbers_parser.generated.TSACommandArchives_sos_pb2 as TSACommandArchives__sos__pb2
import numbers_parser.generated.TSKArchives_pb2 as TSKArchives__pb2
import numbers_parser.generated.TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TNCommandArchives_sos.proto',
  package='TNSOS',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bTNCommandArchives_sos.proto\x12\x05TNSOS\x1a\x1cTSACommandArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\"\x96\x01\n-InducedVerifyDocumentWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12 \n\rsheet_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x1f\n\x17sheet_id_list_undefined\x18\x03 \x01(\x08\"\x83\x01\n4InducedVerifyDrawableZOrdersWithServerCommandArchive\x12K\n\x05super\x18\x01 \x02(\x0b\x32<.TSASOS.InducedVerifyDrawableZOrdersWithServerCommandArchive'
  ,
  dependencies=[TSACommandArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,])




_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDocumentWithServerCommandArchive',
  full_name='TNSOS.InducedVerifyDocumentWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TNSOS.InducedVerifyDocumentWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id_list', full_name='TNSOS.InducedVerifyDocumentWithServerCommandArchive.sheet_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id_list_undefined', full_name='TNSOS.InducedVerifyDocumentWithServerCommandArchive.sheet_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=257,
)


_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDrawableZOrdersWithServerCommandArchive',
  full_name='TNSOS.InducedVerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TNSOS.InducedVerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=391,
)

_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['sheet_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSACommandArchives__sos__pb2._INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDocumentWithServerCommandArchive'] = _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDrawableZOrdersWithServerCommandArchive'] = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InducedVerifyDocumentWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDocumentWithServerCommandArchive', (_message.Message,), {
  'DESCRIPTOR' : _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE,
  '__module__' : 'TNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TNSOS.InducedVerifyDocumentWithServerCommandArchive)
  })
_sym_db.RegisterMessage(InducedVerifyDocumentWithServerCommandArchive)

InducedVerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), {
  'DESCRIPTOR' : _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  '__module__' : 'TNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TNSOS.InducedVerifyDrawableZOrdersWithServerCommandArchive)
  })
_sym_db.RegisterMessage(InducedVerifyDrawableZOrdersWithServerCommandArchive)


# @@protoc_insertion_point(module_scope)
